PrinterBarcodes class
Barcode printing functions for Bixolon printers.
This class provides methods for printing various types of barcodes, including 1D barcodes and 2D codes like QR codes.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
printBarcode(
String data, BarcodeType type, {int height = 100, int width = 2, Alignment alignment = Alignment.center, BarcodeTextPosition textPosition = BarcodeTextPosition.below}) → Future< bool> - Print a barcode.
-
printBarcodeWithCaption(
String data, {required String caption, BarcodeType type = BarcodeType.code128, int height = 100, int width = 2, bool showBarcodeText = true}) → Future< bool> - Print a barcode with a caption.
-
printCenteredBarcode(
{required String data, required BarcodeType type, int height = 200, int width = 6, BarcodeTextPosition textPosition = BarcodeTextPosition.below, int? printerWidth}) → Future< bool> - Print a centered barcode with default settings.
-
printCode128Barcode(
{required String barcodeData, String displayText = "", String leftText = "", double height = 38, bool displayValue = true, int textSize = 24, double leftTextWidth = 200, double leftTextPosition = 155, int printerWidth = 576}) → Future< bool> - Print a Code 128 barcode with custom parameters.
-
printProductBarcode(
String sku, {required String price, String? productName, BarcodeType type = BarcodeType.ean13}) → Future< bool> - Print a product barcode with standard formatting.
-
printQRCode(
String data, {int size = 200, Alignment alignment = Alignment.center}) → Future< bool> - Print a QR code.
-
validateBarcodeData(
String data, BarcodeType type) → bool - Validates barcode data for the specified type.